@@ -2,7 +2,7 @@
  * Caja-Actions
  * A Caja extension which offers configurable context menu actions.
  *
- * Copyright (C) 2005 The MATE Foundation
+ * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
  * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
@@ -498,7 +498,7 @@ is_candidate_for_target( const NAIContext *object, guint target, GList *files )
 				break;
 
 			default:
-				g_warning( "%s: unknonw target=%d", thisfn, target );
+				g_warning( "%s: unknown target=%d", thisfn, target );
 				ok = FALSE;
 		}
 	}
